@@ -16,11 +16,11 @@ def main():
 @click.command()
 @click.option('-u', '--url', default='https://github.com/2003100127/deepsmirud/releases/download/model/model.zip', help='URL of deepsmirud models')
 @click.option('-o', '--output_path', default='./model.zip', help='output path of deepsmirud models')
-def download(url, fpn):
+def download(url, output_path):
     print('downloading...')
     urllib.request.urlretrieve(
         url=url,
-        filename=fpn
+        filename=output_path
     )
     print('downloaded!')
     return
